@@ -2404,6 +2404,753 @@ UPDATE pg_proc
 SET protransform=(SELECT oid FROM pg_proc WHERE proname='varchar2_transform')
 WHERE proname='nvarchar2';
 
+/* PAD */
+
+/* LPAD family */
+
+/* Incompatibility #1:
+ *     pg_catalog.lpad removes trailing blanks of CHAR arguments
+ *     because of implicit cast to text
+ *
+ * Incompatibility #2:
+ *     pg_catalog.lpad considers character length, NOT display length
+ *     so, add functions to use custom C implementation of lpad as defined
+ *     in charpad.c
+ */
+CREATE FUNCTION oracle.lpad(char, integer, char)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(char, integer, text)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(char, integer, varchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(char, integer, nvarchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(char, integer)
+RETURNS text
+AS $$ SELECT oracle.lpad($1, $2, ' '::text); $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(text, integer, char)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(varchar2, integer, char)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(nvarchar2, integer, char)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(text, integer, text)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(text, integer, varchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(text, integer, nvarchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(text, integer)
+RETURNS text
+AS $$ SELECT oracle.lpad($1, $2, ' '::text); $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(varchar2, integer, text)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(varchar2, integer, varchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(varchar2, integer, nvarchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(varchar2, integer)
+RETURNS text
+AS $$ SELECT oracle.lpad($1, $2, ' '::text); $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(nvarchar2, integer, text)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(nvarchar2, integer, varchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(nvarchar2, integer, nvarchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','lpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.lpad(nvarchar2, integer)
+RETURNS text
+AS $$ SELECT oracle.lpad($1, $2, ' '::text); $$
+LANGUAGE SQL
+STRICT
+;
+
+/* RPAD family */
+
+/* Incompatibility #1:
+ *     pg_catalog.rpad removes trailing blanks of CHAR arguments
+ *     because of implicit cast to text
+ *
+ * Incompatibility #2:
+ *     pg_catalog.rpad considers character length, NOT display length
+ *     so, add functions to use custom C implementation of rpad as defined
+ *     in charpad.c
+ */
+CREATE FUNCTION oracle.rpad(char, integer, char)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(char, integer, text)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(char, integer, varchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(char, integer, nvarchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(char, integer)
+RETURNS text
+AS $$ SELECT oracle.rpad($1, $2, ' '::text); $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(text, integer, char)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(varchar2, integer, char)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(nvarchar2, integer, char)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(text, integer, text)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(text, integer, varchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(text, integer, nvarchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(text, integer)
+RETURNS text
+AS $$ SELECT oracle.rpad($1, $2, ' '::text); $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(varchar2, integer, text)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(varchar2, integer, varchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(varchar2, integer, nvarchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(varchar2, integer)
+RETURNS text
+AS $$ SELECT oracle.rpad($1, $2, ' '::text); $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(nvarchar2, integer, text)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(nvarchar2, integer, varchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(nvarchar2, integer, nvarchar2)
+RETURNS text
+AS 'MODULE_PATHNAME','rpad'
+LANGUAGE 'c'
+STRICT
+;
+
+CREATE FUNCTION oracle.rpad(nvarchar2, integer)
+RETURNS text
+AS $$ SELECT oracle.rpad($1, $2, ' '::text); $$
+LANGUAGE SQL
+STRICT
+;
+
+/* TRIM */
+
+/* Incompatibility #1:
+ *     pg_catalog.ltrim, pg_catalog.rtrim and pg_catalog.btrim remove
+ *     trailing blanks of CHAR arguments because of implicit cast to
+ *     text
+ *
+ *     Following re-definitions address this incompatbility so that
+ *     trailing blanks of CHAR arguments are preserved and considered
+ *     significant for the trimming process.
+ */
+
+/* LTRIM family */
+CREATE FUNCTION oracle.ltrim(char, char)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(char, text)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(char, varchar2)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(char, nvarchar2)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(char)
+RETURNS text
+AS $$ SELECT oracle.ltrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(text, char)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(text, text)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(text, varchar2)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(text, nvarchar2)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(text)
+RETURNS text
+AS $$ SELECT oracle.ltrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(varchar2, char)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(varchar2, text)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(varchar2, varchar2)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(varchar2, nvarchar2)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(varchar2)
+RETURNS text
+AS $$ SELECT oracle.ltrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(nvarchar2, char)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(nvarchar2, text)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(nvarchar2, varchar2)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(nvarchar2, nvarchar2)
+RETURNS text
+AS 'ltrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.ltrim(nvarchar2)
+RETURNS text
+AS $$ SELECT oracle.ltrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+/* RTRIM family */
+CREATE FUNCTION oracle.rtrim(char, char)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(char, text)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(char, varchar2)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(char, nvarchar2)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(char)
+RETURNS text
+AS $$ SELECT oracle.rtrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(text, char)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(text, text)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(text, varchar2)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(text, nvarchar2)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(text)
+RETURNS text
+AS $$ SELECT oracle.rtrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(varchar2, char)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(varchar2, text)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(varchar2, varchar2)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(varchar2, nvarchar2)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(varchar2)
+RETURNS text
+AS $$ SELECT oracle.rtrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(nvarchar2, char)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(nvarchar2, text)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(nvarchar2, varchar2)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(nvarchar2, nvarchar2)
+RETURNS text
+AS 'rtrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.rtrim(nvarchar2)
+RETURNS text
+AS $$ SELECT oracle.rtrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+/* BTRIM family */
+CREATE FUNCTION oracle.btrim(char, char)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(char, text)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(char, varchar2)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(char, nvarchar2)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(char)
+RETURNS text
+AS $$ SELECT oracle.btrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(text, char)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(text, text)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(text, varchar2)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(text, nvarchar2)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(text)
+RETURNS text
+AS $$ SELECT oracle.btrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(varchar2, char)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(varchar2, text)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(varchar2, varchar2)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(varchar2, nvarchar2)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(varchar2)
+RETURNS text
+AS $$ SELECT oracle.btrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(nvarchar2, char)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(nvarchar2, text)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(nvarchar2, varchar2)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(nvarchar2, nvarchar2)
+RETURNS text
+AS 'btrim'
+LANGUAGE internal
+STRICT
+;
+
+CREATE FUNCTION oracle.btrim(nvarchar2)
+RETURNS text
+AS $$ SELECT oracle.btrim($1, ' '::text) $$
+LANGUAGE SQL
+STRICT
+;
+
+/* LENGTH */
+CREATE FUNCTION oracle.length(char)
+RETURNS integer
+AS 'MODULE_PATHNAME','bpcharlen'
+LANGUAGE 'c'
+STRICT
+;
+
 GRANT USAGE ON SCHEMA dbms_pipe TO PUBLIC;
 GRANT USAGE ON SCHEMA dbms_alert TO PUBLIC;
 GRANT USAGE ON SCHEMA plvdate TO PUBLIC;
