@@ -1,5 +1,8 @@
 /* contrib/orafce/orafce--unpackaged--3.0.sql */
 
+-- complain if script is sourced in psql, rather than via CREATE EXTENSION
+\echo Use "CREATE EXTENSION orafce FROM unpackaged" to load this file. \quit
+
 ALTER EXTENSION orafce ADD function pg_catalog.trunc(value date, fmt text);
 ALTER EXTENSION orafce ADD function pg_catalog.round(value date, fmt text);
 ALTER EXTENSION orafce ADD function pg_catalog.next_day(value date, weekday text);
@@ -26,6 +29,8 @@ ALTER EXTENSION orafce ADD function pg_catalog.to_char(num real);
 ALTER EXTENSION orafce ADD function pg_catalog.to_char(num double precision);
 ALTER EXTENSION orafce ADD function pg_catalog.to_char(num numeric);
 ALTER EXTENSION orafce ADD function pg_catalog.to_number(str text);
+ALTER EXTENSION orafce ADD function pg_catalog.to_number(numeric);
+ALTER EXTENSION orafce ADD function pg_catalog.to_number(numeric,numeric)
 ALTER EXTENSION orafce ADD function pg_catalog.to_date(str text);
 ALTER EXTENSION orafce ADD function to_multi_byte(str text);
 ALTER EXTENSION orafce ADD function bitand(bigint, bigint);
@@ -49,6 +54,10 @@ ALTER EXTENSION orafce ADD function pg_catalog.lnnvl(bool);
 ALTER EXTENSION orafce ADD schema oracle;
 ALTER EXTENSION orafce ADD function oracle.substr(str text, start int);
 ALTER EXTENSION orafce ADD function oracle.substr(str text, start int, len int);
+ALTER EXTENSION orafce ADD function oracle.substr(numeric,numeric);
+ALTER EXTENSION orafce ADD function oracle.substr(numeric, numeric, numeric);
+ALTER EXTENSION orafce ADD function oracle.substr(varchar, numeric);
+ALTER EXTENSION orafce ADD function oracle.substr(varchar, numeric,numeric);
 ALTER EXTENSION orafce ADD function oracle.to_date(text);
 ALTER EXTENSION orafce ADD function oracle.to_date(TEXT,TEXT);
 ALTER EXTENSION orafce ADD function oracle.add_days_to_timestamp(oracle.date,integer);
