@@ -23,7 +23,7 @@
 
 #include "catalog/pg_type.h"
 #include "libpq/pqformat.h"
-#include "orafunc.h"
+#include "orafce.h"
 #include "builtins.h"
 
 PG_FUNCTION_INFO_V1(plvstr_rvrs);
