@@ -1,11 +1,12 @@
 -- Tests for nlssort
 \set ECHO none
-SET client_min_messages = warning;
+SET client_min_messages = error;
 DROP DATABASE IF EXISTS regression_sort;
 CREATE DATABASE regression_sort WITH TEMPLATE = template0 ENCODING='SQL_ASCII' LC_COLLATE='C' LC_CTYPE='C';
 \c regression_sort
-\set ECHO none
-\i orafunc.sql
+SET client_min_messages = error;
+\i orafce.sql
+SET client_min_messages = default;
 CREATE TABLE test_sort (name TEXT);
 INSERT INTO test_sort VALUES ('red'), ('brown'), ('yellow'), ('Purple');
 SELECT * FROM test_sort ORDER BY NLSSORT(name, 'en_US.utf8');
