@@ -779,3 +779,155 @@ SELECT (to_date('January 15, 1990, 11:00 A.M.','Month dd, YYYY, HH:MI A.M.') - t
 SELECT (to_date('14-Jul14 11:44:49' ,'YY-MonDD HH24:MI:SS') - to_date('14-Jan14 12:44:49' ,'YY-MonDD HH24:MI:SS'))::numeric(10,4);
 SELECT (to_date('210514 12:13:44','DDMMYY HH24:MI:SS') - to_date('210114 10:13:44','DDMMYY HH24:MI:SS'))::numeric(10,4);
 SET search_path TO default;
+
+--
+-- Note: each Japanese character used below has display width of 2, otherwise 1.
+-- Note: each output string is surrounded by '|' for improved readability
+--
+
+--
+-- test LPAD family of functions
+--
+
+/* cases where one or more arguments are of type CHAR */
+SELECT '|' || oracle.lpad('あbcd'::char(8), 10) || '|';
+SELECT '|' || oracle.lpad('あbcd'::char(8),  5) || '|';
+SELECT '|' || oracle.lpad('あbcd'::char(8), 1) || '|';
+
+SELECT '|' || oracle.lpad('あbcd'::char(5), 10, 'xい'::char(3)) || '|';
+SELECT '|' || oracle.lpad('あbcd'::char(5),  5, 'xい'::char(3)) || '|';
+
+SELECT '|' || oracle.lpad('あbcd'::char(5), 10, 'xい'::text) || '|';
+SELECT '|' || oracle.lpad('あbcd'::char(5), 10, 'xい'::varchar2(5)) || '|';
+SELECT '|' || oracle.lpad('あbcd'::char(5), 10, 'xい'::nvarchar2(3)) || '|';
+
+SELECT '|' || oracle.lpad('あbcd'::text, 10, 'xい'::char(3)) || '|';
+SELECT '|' || oracle.lpad('あbcd'::text,  5, 'xい'::char(3)) || '|';
+
+SELECT '|' || oracle.lpad('あbcd'::varchar2(5), 10, 'xい'::char(3)) || '|';
+SELECT '|' || oracle.lpad('あbcd'::varchar2(5),  5, 'xい'::char(3)) || '|';
+
+SELECT '|' || oracle.lpad('あbcd'::nvarchar2(5), 10, 'xい'::char(3)) || '|';
+SELECT '|' || oracle.lpad('あbcd'::nvarchar2(5),  5, 'xい'::char(3)) || '|';
+
+/* test oracle.lpad(text, int [, text]) */
+SELECT '|' || oracle.lpad('あbcd'::text, 10) || '|';
+SELECT '|' || oracle.lpad('あbcd'::text,  5) || '|';
+
+SELECT '|' || oracle.lpad('あbcd'::varchar2(10), 10) || '|';
+SELECT '|' || oracle.lpad('あbcd'::varchar2(10), 5) || '|';
+
+SELECT '|' || oracle.lpad('あbcd'::nvarchar2(10), 10) || '|';
+SELECT '|' || oracle.lpad('あbcd'::nvarchar2(10), 5) || '|';
+
+SELECT '|' || oracle.lpad('あbcd'::text, 10, 'xい'::text) || '|';
+SELECT '|' || oracle.lpad('あbcd'::text, 10, 'xい'::varchar2(5)) || '|';
+SELECT '|' || oracle.lpad('あbcd'::text, 10, 'xい'::nvarchar2(3)) || '|';
+
+SELECT '|' || oracle.lpad('あbcd'::varchar2(5), 10, 'xい'::text) || '|';
+SELECT '|' || oracle.lpad('あbcd'::varchar2(5), 10, 'xい'::varchar2(5)) || '|';
+SELECT '|' || oracle.lpad('あbcd'::varchar2(5), 10, 'xい'::nvarchar2(5)) || '|';
+
+SELECT '|' || oracle.lpad('あbcd'::nvarchar2(5), 10, 'xい'::text) || '|';
+SELECT '|' || oracle.lpad('あbcd'::nvarchar2(5), 10, 'xい'::varchar2(5)) || '|';
+SELECT '|' || oracle.lpad('あbcd'::nvarchar2(5), 10, 'xい'::nvarchar2(5)) || '|';
+
+--
+-- test RPAD family of functions
+--
+
+/* cases where one or more arguments are of type CHAR */
+SELECT '|' || oracle.rpad('あbcd'::char(8), 10) || '|';
+SELECT '|' || oracle.rpad('あbcd'::char(8),  5) || '|';
+SELECT '|' || oracle.rpad('あbcd'::char(8), 1) || '|';
+
+SELECT '|' || oracle.rpad('あbcd'::char(5), 10, 'xい'::char(3)) || '|';
+SELECT '|' || oracle.rpad('あbcd'::char(5),  5, 'xい'::char(3)) || '|';
+
+SELECT '|' || oracle.rpad('あbcd'::char(5), 10, 'xい'::text) || '|';
+SELECT '|' || oracle.rpad('あbcd'::char(5), 10, 'xい'::varchar2(5)) || '|';
+SELECT '|' || oracle.rpad('あbcd'::char(5), 10, 'xい'::nvarchar2(3)) || '|';
+
+SELECT '|' || oracle.rpad('あbcd'::text, 10, 'xい'::char(3)) || '|';
+SELECT '|' || oracle.rpad('あbcd'::text,  5, 'xい'::char(3)) || '|';
+
+SELECT '|' || oracle.rpad('あbcd'::varchar2(5), 10, 'xい'::char(3)) || '|';
+SELECT '|' || oracle.rpad('あbcd'::varchar2(5),  5, 'xい'::char(3)) || '|';
+
+SELECT '|' || oracle.rpad('あbcd'::nvarchar2(5), 10, 'xい'::char(3)) || '|';
+SELECT '|' || oracle.rpad('あbcd'::nvarchar2(5),  5, 'xい'::char(3)) || '|';
+
+/* test oracle.lpad(text, int [, text]) */
+SELECT '|' || oracle.rpad('あbcd'::text, 10) || '|';
+SELECT '|' || oracle.rpad('あbcd'::text,  5) || '|';
+
+SELECT '|' || oracle.rpad('あbcd'::varchar2(10), 10) || '|';
+SELECT '|' || oracle.rpad('あbcd'::varchar2(10), 5) || '|';
+
+SELECT '|' || oracle.rpad('あbcd'::nvarchar2(10), 10) || '|';
+SELECT '|' || oracle.rpad('あbcd'::nvarchar2(10), 5) || '|';
+
+SELECT '|' || oracle.rpad('あbcd'::text, 10, 'xい'::text) || '|';
+SELECT '|' || oracle.rpad('あbcd'::text, 10, 'xい'::varchar2(5)) || '|';
+SELECT '|' || oracle.rpad('あbcd'::text, 10, 'xい'::nvarchar2(3)) || '|';
+
+SELECT '|' || oracle.rpad('あbcd'::varchar2(5), 10, 'xい'::text) || '|';
+SELECT '|' || oracle.rpad('あbcd'::varchar2(5), 10, 'xい'::varchar2(5)) || '|';
+SELECT '|' || oracle.rpad('あbcd'::varchar2(5), 10, 'xい'::nvarchar2(5)) || '|';
+
+SELECT '|' || oracle.rpad('あbcd'::nvarchar2(5), 10, 'xい'::text) || '|';
+SELECT '|' || oracle.rpad('あbcd'::nvarchar2(5), 10, 'xい'::varchar2(5)) || '|';
+SELECT '|' || oracle.rpad('あbcd'::nvarchar2(5), 10, 'xい'::nvarchar2(5)) || '|';
+
+--
+-- test TRIM family of functions
+--
+
+/* test that trailing blanks of CHAR arguments are not removed and are significant */
+
+--
+-- LTRIM
+--
+SELECT '|' || oracle.ltrim(' abcd'::char(10)) || '|' as LTRIM;
+SELECT '|' || oracle.ltrim(' abcd'::char(10),'a'::char(3)) || '|' as LTRIM;
+SELECT '|' || oracle.ltrim(' abcd'::char(10),'a'::text) || '|' as LTRIM;
+SELECT '|' || oracle.ltrim(' abcd'::char(10),'a'::varchar2(3)) || '|' as LTRIM;
+SELECT '|' || oracle.ltrim(' abcd'::char(10),'a'::nvarchar2(3)) || '|' as LTRIM;
+
+SELECT '|' || oracle.ltrim(' abcd  '::text,'a'::char(3)) || '|' as LTRIM;
+SELECT '|' || oracle.ltrim(' abcd  '::varchar2(10),'a'::char(3)) || '|' as LTRIM;
+SELECT '|' || oracle.ltrim(' abcd  '::nvarchar2(10),'a'::char(3)) || '|' as LTRIM;
+
+--
+-- RTRIM
+--
+SELECT '|' || oracle.rtrim(' abcd'::char(10)) || '|' as LTRIM;
+SELECT '|' || oracle.rtrim(' abcd'::char(10),'d'::char(3)) || '|' as LTRIM;
+SELECT '|' || oracle.rtrim(' abcd'::char(10),'d'::text) || '|' as LTRIM;
+SELECT '|' || oracle.rtrim(' abcd'::char(10),'d'::varchar2(3)) || '|' as LTRIM;
+SELECT '|' || oracle.rtrim(' abcd'::char(10),'d'::nvarchar2(3)) || '|' as LTRIM;
+
+SELECT '|' || oracle.rtrim(' abcd  '::text,'d'::char(3)) || '|' as LTRIM;
+SELECT '|' || oracle.rtrim(' abcd  '::varchar2(10),'d'::char(3)) || '|' as LTRIM;
+SELECT '|' || oracle.rtrim(' abcd  '::nvarchar2(10),'d'::char(3)) || '|' as LTRIM;
+
+--
+-- BTRIM
+--
+SELECT '|' || oracle.btrim(' abcd'::char(10)) || '|' as LTRIM;
+SELECT '|' || oracle.btrim(' abcd'::char(10),'ad'::char(3)) || '|' as LTRIM;
+SELECT '|' || oracle.btrim(' abcd'::char(10),'ad'::text) || '|' as LTRIM;
+SELECT '|' || oracle.btrim(' abcd'::char(10),'ad'::varchar2(3)) || '|' as LTRIM;
+SELECT '|' || oracle.btrim(' abcd'::char(10),'ad'::nvarchar2(3)) || '|' as LTRIM;
+
+SELECT '|' || oracle.btrim(' abcd  '::text,'d'::char(3)) || '|' as LTRIM;
+SELECT '|' || oracle.btrim(' abcd  '::varchar2(10),'d'::char(3)) || '|' as LTRIM;
+SELECT '|' || oracle.btrim(' abcd  '::nvarchar2(10),'d'::char(3)) || '|' as LTRIM;
+
+--
+-- test oracle.length()
+--
+
+/* test that trailing blanks are not ignored */
+SELECT oracle.length('あbb'::char(6));
+SELECT oracle.length(''::char(6));
